@@ -147,6 +147,10 @@ int add_job_to_queue(gearman_client_st **client, gm_server_t * server_list[GM_LI
 
     gettimeofday(&t1,NULL);
     size = mod_gm_encrypt(ctx, &crypted_data, data, transport_mode);
+    if(size <= 0) {
+        gm_log( GM_LOG_ERROR, "encrypting job failed\n" );
+        return GM_ERROR;
+    }
     gm_log( GM_LOG_TRACE, "%d +++>\n%s\n<+++\n", size, crypted_data );
 
     if( priority == GM_JOB_PRIO_LOW ) {
@@ -340,7 +344,8 @@ int get_gearman_server_data(mod_gm_server_status_t *stats, char ** message, char
 
 /* send gearman admin */
 int send2gearmandadmin(char * cmd, char * hostnam, int port, char ** output, char ** error) {
-    int sockfd, n;
+    int sockfd = -1;
+    int n;
     char buf[GM_BUFFERSIZE];
 
     *error  = gm_malloc(GM_BUFFERSIZE);
@@ -351,6 +356,9 @@ int send2gearmandadmin(char * cmd, char * hostnam, int port, char ** output, cha
     if(gm_net_connect(hostnam, port, &sockfd, error) != GM_OK) {
         return(STATE_CRITICAL);
     }
+    if(sockfd <= 0) {
+        return(STATE_CRITICAL);
+    }
 
     gm_log( GM_LOG_TRACE, "sending '%s' to %s on port %i\n", cmd, hostnam, port );
     n = write(sockfd,cmd,strlen(cmd));
