@@ -92,6 +92,7 @@ static void  move_results_to_core(struct nm_event_execution_properties *evprop);
 static int   handle_hst_check_result(int event_type, void *data);
 static int   handle_svc_check_result(int event_type, void *data);
 static int   try_check_dummy(const char *, host *, service * );
+static int   xpddefault_preprocess_file_templates(char *);
 void shutdown_threads(void);
 void process_check_result_list(void);
 static int start_threads(void);
@@ -162,6 +163,10 @@ int nebmodule_init( int flags, char *args, nebmodule *handle ) {
         return NEB_ERROR;
     }
 
+    /* initialize templates*/
+	xpddefault_preprocess_file_templates(mod_gm_opt->host_perfdata_template);
+	xpddefault_preprocess_file_templates(mod_gm_opt->service_perfdata_template);
+
     /* init crypto functions */
     if(mod_gm_opt->encryption == GM_ENABLED) {
         if(mod_gm_opt->crypt_key == NULL) {
@@ -292,10 +297,17 @@ int nebmodule_deinit( int flags, int reason ) {
     mod_gm_free_opt(mod_gm_opt);
 
     mod_gm_crypt_deinit(mod_ctx);
+
+    if(reason == NEBMODULE_NEB_SHUTDOWN) {
+        // breaks reloading the module and usually done automatically at exit, but at exit
+        // this modules is already unloaded
+        OPENSSL_cleanup();
+    }
+
     return NEB_OK;
 }
 
-void shutdown_threads() {
+void shutdown_threads(void) {
     int x = 0;
 
     gm_should_terminate = TRUE;
@@ -326,7 +338,7 @@ static void move_results_to_core(struct nm_event_execution_properties *evprop) {
     schedule_event(1, move_results_to_core, NULL);
 }
 
-void process_check_result_list() {
+void process_check_result_list(void) {
     objectlist *tmp_list = NULL;
     objectlist *cur = NULL;
     struct timeval tval_before, tval_after, tval_result;
@@ -1478,7 +1490,9 @@ int handle_perfdata(int event_type, void *data) {
     host *hst        = NULL;
     service *svc     = NULL;
     int has_perfdata = FALSE;
-    char *perf_data;
+    nagios_macros mac;
+    char *raw_output = NULL;
+    char *processed_output = NULL;
 
     gm_log( GM_LOG_TRACE, "handle_perfdata(%d)\n", event_type );
     if(process_performance_data == 0) {
@@ -1490,7 +1504,7 @@ int handle_perfdata(int event_type, void *data) {
     switch (event_type) {
 
         case NEBCALLBACK_HOST_CHECK_DATA:
-            /* an aggregated status data dump just started or ended */
+            /* incoming host check result */
             if ((hostchkdata = (nebstruct_host_check_data *) data)) {
 
                 if (hostchkdata->type != NEBTYPE_HOSTCHECK_PROCESSED || hostchkdata->perf_data == NULL ) {
@@ -1503,31 +1517,25 @@ int handle_perfdata(int event_type, void *data) {
                     break;
                 }
 
-                /* replace newlines with actual newlines */
-                perf_data = replace_str(hostchkdata->perf_data, "\\n", "\n");
+                memset(&mac, 0, sizeof(mac));
+                grab_host_macros_r(&mac, hst);
 
-                temp_buffer[0]='\x0';
-                snprintf( temp_buffer,GM_MAX_OUTPUT-1,
-                            "DATATYPE::HOSTPERFDATA\t"
-                            "TIMET::%d\t"
-                            "HOSTNAME::%s\t"
-                            "HOSTPERFDATA::%s\t"
-                            "HOSTCHECKCOMMAND::%s!%s\t"
-                            "HOSTSTATE::%d\t"
-                            "HOSTSTATETYPE::%d\n"
-                            "HOSTINTERVAL::%f\n\n",
-                            (int)hostchkdata->timestamp.tv_sec,
-                            hostchkdata->host_name, perf_data,
-                            hostchkdata->command_name, hostchkdata->command_args,
-                            hostchkdata->state, hostchkdata->state_type,
-                            hst->check_interval);
+                gm_asprintf(&raw_output, "%s\n", mod_gm_opt->host_perfdata_template);
+                gm_log( GM_LOG_TRACE, "handle_perfdata() raw host template: %s\n", raw_output );
+
+                process_macros_r(&mac, raw_output, &processed_output, 0);
+                if(processed_output == NULL) {
+                    gm_free(raw_output);
+                    return ERROR;
+                }
+
+                gm_log( GM_LOG_TRACE, "handle_perfdata() processed host template: %s\n", processed_output );
                 has_perfdata = TRUE;
-                free(perf_data);
             }
             break;
 
         case NEBCALLBACK_SERVICE_CHECK_DATA:
-            /* an aggregated status data dump just started or ended */
+            /* incoming service check result */
             if ((srvchkdata = (nebstruct_service_check_data *) data)) {
 
                 if(srvchkdata->type != NEBTYPE_SERVICECHECK_PROCESSED || srvchkdata->perf_data == NULL) {
@@ -1541,28 +1549,20 @@ int handle_perfdata(int event_type, void *data) {
                     break;
                 }
 
-                /* replace newlines with actual newlines */
-                perf_data = replace_str(srvchkdata->perf_data, "\\n", "\n");
+                memset(&mac, 0, sizeof(mac));
+                grab_service_macros_r(&mac, svc);
 
-                temp_buffer[0]='\x0';
-                snprintf( temp_buffer,GM_MAX_OUTPUT-1,
-                            "DATATYPE::SERVICEPERFDATA\t"
-                            "TIMET::%d\t"
-                            "HOSTNAME::%s\t"
-                            "SERVICEDESC::%s\t"
-                            "SERVICEPERFDATA::%s\t"
-                            "SERVICECHECKCOMMAND::%s\t"
-                            "SERVICESTATE::%d\t"
-                            "SERVICESTATETYPE::%d\n"
-                            "SERVICEINTERVAL::%f\n\n",
-                            (int)srvchkdata->timestamp.tv_sec,
-                            srvchkdata->host_name, srvchkdata->service_description,
-                            perf_data, svc->check_command,
-                            srvchkdata->state, srvchkdata->state_type,
-                            svc->check_interval);
-                temp_buffer[GM_MAX_OUTPUT-1]='\x0';
+                gm_asprintf(&raw_output, "%s\n", mod_gm_opt->service_perfdata_template);
+                gm_log( GM_LOG_TRACE, "handle_perfdata() raw host template: %s\n", raw_output );
+
+                process_macros_r(&mac, raw_output, &processed_output, 0);
+                if(processed_output == NULL) {
+                    gm_free(raw_output);
+                    return ERROR;
+                }
+
+                gm_log( GM_LOG_TRACE, "handle_perfdata() processed service template: %s\n", processed_output );
                 has_perfdata = TRUE;
-                free(perf_data);
             }
             break;
 
@@ -1592,7 +1592,7 @@ int handle_perfdata(int event_type, void *data) {
                                  mod_gm_opt->server_list,
                                  perfdata_queue,
                                  (mod_gm_opt->perfdata_mode == GM_PERFDATA_OVERWRITE ? uniq : NULL),
-                                 temp_buffer,
+                                 processed_output,
                                  GM_JOB_PRIO_NORMAL,
                                  GM_DEFAULT_JOB_RETRIES,
                                  mod_gm_opt->transportmode,
@@ -1608,6 +1608,9 @@ int handle_perfdata(int event_type, void *data) {
         }
     }
 
+    gm_free(processed_output);
+    gm_free(raw_output);
+
     return 0;
 }
 
@@ -2150,3 +2153,40 @@ static int try_check_dummy(const char * command_line, host * hst, service * svc)
 
     return(GM_OK);
 }
+
+/* processes delimiter characters in templates (adopted from naemon-core source )*/
+static int xpddefault_preprocess_file_templates(char *template)
+{
+	char *tempbuf;
+	unsigned int x, y;
+
+	if (template == NULL)
+		return OK;
+
+	/* allocate temporary buffer */
+	tempbuf = gm_malloc(strlen(template) + 1);
+	strcpy(tempbuf, "");
+
+	for (x = 0, y = 0; x < strlen(template); x++, y++) {
+		if (template[x] == '\\') {
+			if (template[x + 1] == 't') {
+				tempbuf[y] = '\t';
+				x++;
+			} else if (template[x + 1] == 'r') {
+				tempbuf[y] = '\r';
+				x++;
+			} else if (template[x + 1] == 'n') {
+				tempbuf[y] = '\n';
+				x++;
+			} else
+				tempbuf[y] = template[x];
+		} else
+			tempbuf[y] = template[x];
+	}
+	tempbuf[y] = '\x0';
+
+	strcpy(template, tempbuf);
+	gm_free(tempbuf);
+
+	return OK;
+}
